@@ -11,9 +11,7 @@ from kafka import KafkaProducer as _KafkaProducer
 class KafkaProducer(object):
 
     def __init__(self, **config):
-        self._producer = _KafkaProducer(**config)
+        self._producer:_KafkaProducer = _KafkaProducer(**config)
 
     def __getattr__(self, item):
-        if hasattr(self, item):
-            return getattr(self, item)
         return getattr(self._producer, item)
